@@ -1,4 +1,4 @@
-# ImConfig.py (c) 2012-2016 Canonical
+# ImConfig.py (c) 2012-2017 Canonical
 # Author: Gunnar Hjalmarsson <gunnarhj@ubuntu.com>
 #
 # Released under the GPL
@@ -36,6 +36,7 @@ class ImConfig(object):
             locale.setlocale(locale.LC_ALL, '')
         except locale.Error:
             return None
+        loc = locale.getlocale(locale.LC_CTYPE)[0]
         desktop = os.environ.get('XDG_CURRENT_DESKTOP')
         if not desktop:
             return None
@@ -45,7 +46,7 @@ class ImConfig(object):
                 found = True
                 break
         if found and desktop.split(':')[0] != 'GNOME-Flashback' \
-          or locale.getlocale(locale.LC_CTYPE)[0][:3] in ['zh_', 'ja_', 'ko_', 'vi_']:
+          or loc and loc[:3] in ['zh_', 'ja_', 'ko_', 'vi_']:
             system_default = autoConfig
         else:
             system_default = 'none'
